@@ -9,5 +9,5 @@ class SkipParser(AbstractSkipParser):
 
     def __init__(self) -> None:
         super().__init__([
-            DirectiveInHTMLCommentLexer('skip'),
+            DirectiveInHTMLCommentLexer(self.directive),
         ])
