@@ -4,18 +4,17 @@ This is a module doc string.
 import re
 from functools import partial
 from pathlib import Path
-from typing import Iterable
+from collections.abc import Iterable
 
 from testfixtures import compare, ShouldRaise
 
 from sybil import Region, Example
 from sybil.document import PythonDocStringDocument, Document
 from sybil.example import NotEvaluated, SybilFailure
-from sybil.exceptions import LexingException
-from .helpers import ast_docstrings, skip_if_37_or_older, parse, sample_path
+from sybil.parsers.abstract.lexers import LexingException
+from .helpers import ast_docstrings, parse, sample_path
 
 
-@skip_if_37_or_older()
 def test_extract_docstring():
     """
     This is a function docstring.
@@ -27,17 +26,17 @@ def test_extract_docstring():
     compare(expected, actual=[python_source_code[s:e] for s, e, _ in actual], show_whitespace=True)
 
 
-@skip_if_37_or_older()
 def test_all_docstrings_extracted_correctly(python_file):
     problems = []
     path, source = python_file
     expected = list(ast_docstrings(source))
     actual = list(PythonDocStringDocument.extract_docstrings(source))
-    check = partial(compare, prefix=str(path), raises=False, show_whitespace=True)
+    actual_from_start_end = [source[s:e].replace('\\"', '"') for s, e, _ in actual]
+    check = partial(compare, raises=False, show_whitespace=True)
     for check_result in (
-        check(expected=len(expected), actual=len(actual)),
-        check(expected, actual=[text for _, _, text in actual]),
-        check(expected, actual=[source[s:e] for s, e, _ in actual]),
+        check(expected=len(expected), actual=len(actual), prefix=f'{path}: number'),
+        check(expected, actual=[text for _, _, text in actual], prefix=f'{path}: content'),
+        check(expected, actual=actual_from_start_end, prefix=f'{path}: start/end'),
     ):
         if check_result:  # pragma: no cover - Only on failures!
             problems.append(check_result)
@@ -55,7 +54,7 @@ def test_evaluator_returns_non_string():
         yield Region(0, 1, None, evaluator)
 
     examples, namespace = parse('sample1.txt', parser, expected=1)
-    with ShouldRaise(SybilFailure(examples[0], f'NotEvaluated()')):
+    with ShouldRaise(SybilFailure(examples[0], 'NotEvaluated()')):
         examples[0].evaluate()
 
 
@@ -149,12 +148,3 @@ def test_nested_evaluators_not_evaluated_from_region():
     examples, namespace = parse('sample1.txt', parser, expected=1)
     with ShouldRaise(SybilFailure(examples[0], f'{evaluator!r} should not raise NotEvaluated()')):
         examples[0].evaluate()
-
-
-def test_find_region_sources_bad_end_match():
-    path = sample_path('lexing-fail.txt')
-    document = Document(Path(path).read_text(), path)
-    with ShouldRaise(LexingException(f"Could not match 'END' in {path}:\n'\\nEDN\\n'")):
-        tuple(document.find_region_sources(
-            start_pattern=re.compile('START'), end_pattern=re.compile('END'),
-        ))
