@@ -5,15 +5,19 @@ from testfixtures import ShouldRaise, compare
 from testfixtures.comparison import compare_text, compare_dict
 
 from sybil import Lexeme
-from sybil.exceptions import LexingException
-from sybil.parsers.abstract.lexers import BlockLexer
+from sybil.parsers.abstract.lexers import BlockLexer, LexingException
 from .helpers import lex, sample_path
 
 
 def test_examples_from_parsing_tests():
     lexer = BlockLexer(start_pattern=re.compile('START'), end_pattern_template='END')
     path = sample_path('lexing-fail.txt')
-    with ShouldRaise(LexingException(f"Could not match 'END' in {path}:\n'\\nEDN\\n'")):
+    with ShouldRaise(
+            LexingException(
+                f"Could not find end of 'START', starting at line 1, column 1, "
+                f"looking for 'END' in {path}:\n'\\nEDN\\n'"
+            )
+    ):
         lex('lexing-fail.txt', lexer)
 
 
